#
# spec file for package perl-File-Touch
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name File-Touch
Name:           perl-File-Touch
Version:        0.12
Release:        1.17
Summary:        Update file access and modification times, optionally creating files if needed
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/N/NE/NEILB/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Time::HiRes) >= 1.9764
Requires:       perl(Time::HiRes) >= 1.9764
%{perl_requires}

%description
This module provides both a functional and OO interface for changing the
file access and modification times on files. It can optionally create the
file for you, if it doesn't exist.

*Note*: you should specify a minimum version of 0.12, as per the SYNOPSIS,
as that fixed an issue that affected systems that have sub-second
granularity on those file times.

Here's a list of arguments that can be used with the object-oriented
contruction:

* atime_only => [0|1]

If nonzero, change only the access time of files. Default is zero.

* mtime_only => [0|1]

If nonzero, change only the modification time of files. Default is zero.

* no_create => [0|1]

If nonzero, do not create new files. Default is zero.

* reference => $reference_file

If defined, use timestamps from this file instead of current time. The
timestamps are read from the reference file when the object is created, not
when '<-'touch>> is invoked. Default is undefined.

* time => $time

If defined, then this value will be used for both access time and
modification time, whichever of those are set. This time is overridden by
the 'atime' and 'mtime' arguments, if you use them.

* atime => $time

If defined, use this time (in epoch seconds) instead of current time for
access time.

* mtime => $time

If defined, use this time (in epoch seconds) instead of current time for
modification time.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sun Mar 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.12
  see /usr/share/doc/packages/perl-File-Touch/Changes
  0.12 2021-03-20 NEILB
  - Fix for RT#128243, where touching a file in close succession wouldn't
    register the second one for make & other purposes, on systems that
    have finer granularity than seconds. Thanks to Slaven Rezic for
    the suggested fix.
  - Improved opening paragraphs of the DESCRIPTION, including a suggestion
    to always require 0.12 or higher.
  0.11_03 2021-03-18 NEILB
  - Time::HiRes doesn't provide utime() on Windows, so now we try and
    load Time::HiRes in a BEGIN block, and only enforce the min version
    if it loaded ok.
  0.11_02 2021-03-18 NEILB
  - Looks like I should have specified a min version of
    Time::HiRes. Was getting some fails from CPAN Testers,
    about utime() not being available.
  0.11_01 2021-03-17 NEILB
  - Try Slaven's suggested fix for RT#128243
* Mon Aug 15 2016 rjschwei@suse.com
- Include in SLE 12 Public Cloud Module (bsc#993765,FATE#320820)
* Fri Mar 11 2016 coolo@suse.com
- updated to 0.11
  see /usr/share/doc/packages/perl-File-Touch/Changes
  0.11 2016-11-26 NEILB
  - Document when reference gras the timestamps, and give example.
    Thanks to SMYLERS for the PR with this.
* Sun Oct 25 2015 coolo@suse.com
- updated to 0.10
  see /usr/share/doc/packages/perl-File-Touch/Changes
  0.10 2015-10-24 NEILB
  - Added [MetaJSON] to dist.ini, so we get a META.json in the release
  - Auto tag and push to github on release
  - Updated repo URL after changing my github username
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.09
  see /usr/share/doc/packages/perl-File-Touch/Changes
* Sat Feb  7 2015 rjschwei@suse.com
- Spec file changes to meet stricter SLE 12 rules
* Sun May  1 2011 coolo@opensuse.org
- initial package 0.08
  * created by cpanspec 1.78.04
